@@ -25,32 +25,29 @@ class ContinuouslyPushRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'ContinuouslyPush')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_MessageId(self):
+	def get_MessageId(self): # String
 		return self.get_query_params().get('MessageId')
 
-	def set_MessageId(self,MessageId):
-		self.add_query_param('MessageId',MessageId)
-
-	def get_Target(self):
+	def set_MessageId(self, MessageId):  # String
+		self.add_query_param('MessageId', MessageId)
+	def get_Target(self): # String
 		return self.get_query_params().get('Target')
 
-	def set_Target(self,Target):
-		self.add_query_param('Target',Target)
-
-	def get_AppKey(self):
+	def set_Target(self, Target):  # String
+		self.add_query_param('Target', Target)
+	def get_AppKey(self): # Long
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
-
-	def get_TargetValue(self):
+	def set_AppKey(self, AppKey):  # Long
+		self.add_query_param('AppKey', AppKey)
+	def get_TargetValue(self): # String
 		return self.get_query_params().get('TargetValue')
 
-	def set_TargetValue(self,TargetValue):
-		self.add_query_param('TargetValue',TargetValue)
\ No newline at end of file
+	def set_TargetValue(self, TargetValue):  # String
+		self.add_query_param('TargetValue', TargetValue)
