@@ -25,38 +25,34 @@ class QueryDeviceStatRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'QueryDeviceStat')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EndTime(self):
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_StartTime(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_StartTime(self): # String
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_DeviceType(self):
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_DeviceType(self): # String
 		return self.get_query_params().get('DeviceType')
 
-	def set_DeviceType(self,DeviceType):
-		self.add_query_param('DeviceType',DeviceType)
-
-	def get_AppKey(self):
+	def set_DeviceType(self, DeviceType):  # String
+		self.add_query_param('DeviceType', DeviceType)
+	def get_AppKey(self): # Long
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
-
-	def get_QueryType(self):
+	def set_AppKey(self, AppKey):  # Long
+		self.add_query_param('AppKey', AppKey)
+	def get_QueryType(self): # String
 		return self.get_query_params().get('QueryType')
 
-	def set_QueryType(self,QueryType):
-		self.add_query_param('QueryType',QueryType)
\ No newline at end of file
+	def set_QueryType(self, QueryType):  # String
+		self.add_query_param('QueryType', QueryType)
