@@ -25,20 +25,19 @@ class QueryDevicesByAccountRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'QueryDevicesByAccount')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AppKey(self):
+	def get_AppKey(self): # Long
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
-
-	def get_Account(self):
+	def set_AppKey(self, AppKey):  # Long
+		self.add_query_param('AppKey', AppKey)
+	def get_Account(self): # String
 		return self.get_query_params().get('Account')
 
-	def set_Account(self,Account):
-		self.add_query_param('Account',Account)
\ No newline at end of file
+	def set_Account(self, Account):  # String
+		self.add_query_param('Account', Account)
