@@ -25,20 +25,19 @@ class QueryDevicesByAliasRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'QueryDevicesByAlias')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Alias(self):
+	def get_Alias(self): # String
 		return self.get_query_params().get('Alias')
 
-	def set_Alias(self,Alias):
-		self.add_query_param('Alias',Alias)
-
-	def get_AppKey(self):
+	def set_Alias(self, Alias):  # String
+		self.add_query_param('Alias', Alias)
+	def get_AppKey(self): # Long
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
\ No newline at end of file
+	def set_AppKey(self, AppKey):  # Long
+		self.add_query_param('AppKey', AppKey)
