@@ -25,32 +25,29 @@ class QueryPushStatByAppRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Push', '2016-08-01', 'QueryPushStatByApp')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EndTime(self):
+	def get_EndTime(self): # String
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_StartTime(self):
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
+	def get_StartTime(self): # String
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_Granularity(self):
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
+	def get_Granularity(self): # String
 		return self.get_query_params().get('Granularity')
 
-	def set_Granularity(self,Granularity):
-		self.add_query_param('Granularity',Granularity)
-
-	def get_AppKey(self):
+	def set_Granularity(self, Granularity):  # String
+		self.add_query_param('Granularity', Granularity)
+	def get_AppKey(self): # Long
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self,AppKey):
-		self.add_query_param('AppKey',AppKey)
\ No newline at end of file
+	def set_AppKey(self, AppKey):  # Long
+		self.add_query_param('AppKey', AppKey)
